@@ -9,6 +9,7 @@ OC.L10N.register(
     "Username" : "Brukarnamn",
     "by" : "av",
     "from" : "frå",
+    "Download video" : "Last ned video",
     "Description" : "Skildring",
     "Refresh" : "Oppfrisk",
     "Web address" : "Nettadresse",
@@ -25,6 +26,7 @@ OC.L10N.register(
     "Delete" : "Ta bort",
     "Dismiss" : "Forkast",
     "Settings" : "Innstillingar",
+    "Show all articles" : "Vis alle artiklar",
     "Import" : "Importer",
     "Export" : "Eksporter",
     "Help" : "Hjelp",
